@@ -9,7 +9,11 @@ not_strict_positive_vector <- function(x) {
 }
 
 not_positive_number <- function(x) {
-  length(x) != 1 || not_positive_vector(x)
+  length(x) != 1L || not_positive_vector(x)
+}
+
+not_prob <- function(x) {
+  not_strict_positive_vector(x) || any(x >= 1)
 }
 
 #---- Inclusion probability ----
